@@ -39,13 +39,13 @@ CMYKChoose::CMYKChoose( QWidget* parent, ScColor orig, QString name, ColorList *
 	orig.checkGamut();
 	alertIcon = loadIcon("alert.png");
 	imageA = QPixmap(50,50);
-	imageA.fill(orig.getRawRGBColor());
+	imageA.fill(orig.getDisplayColor());
 	if (orig.isOutOfGamut())
-		paintAlert(alertIcon,imageA, 2, 2);
+		paintAlert(alertIcon,imageA, 2, 2, false);
 	imageN = QPixmap(50,50);
-	imageN.fill(orig.getRawRGBColor());
+	imageN.fill(orig.getDisplayColor());
 	if (orig.isOutOfGamut())
-		paintAlert(alertIcon, imageN, 2, 2);
+		paintAlert(alertIcon, imageN, 2, 2, false);
 	Farbe = orig;
 	QPixmap image0 = SliderPix(180);
 	QPixmap image1 = SliderPix(300);
@@ -371,6 +371,8 @@ CMYKChoose::CMYKChoose( QWidget* parent, ScColor orig, QString name, ColorList *
 	TabStack->raiseWidget(0);
 	setFixedSize(minimumSizeHint());
 	// signals and slots connections
+	QToolTip::add( Regist, "<qt>" + tr( "Choosing this will enable printing this on all plates. Registration colors are used for printer marks such as crop marks, registration marks and the like. These are not typically used in the layout itself." ) + "</qt>");
+	QToolTip::add( Separations, "<qt>" + tr( "Choosing this will make this color a spot color, thus creating another spot when creating plates or separations. This is used most often when a logo or other color needs exact representation or cannot be replicated with CMYK inks. Metallic and fluorescent inks are good examples which cannot be easily replicated with CMYK inks." ) + "</qt>");
 	connect( Cancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
 	connect( Cancel_2, SIGNAL( clicked() ), this, SLOT( Verlassen() ) );
 	connect( CyanSp, SIGNAL( valueChanged(int) ), CyanSL, SLOT( setValue(int) ) );
@@ -459,13 +461,13 @@ QPixmap CMYKChoose::SliderPix(int farbe)
 				switch (farbe)
 				{
 				case 180:
-					tmp = ScColor(x, m, y, k).getRGBColor();
+					tmp = ScColor(x, m, y, k).getDisplayColorGC();
 					break;
 				case 300:
-					tmp = ScColor(c, x, y, k).getRGBColor();
+					tmp = ScColor(c, x, y, k).getDisplayColorGC();
 					break;
 				case 60:
-					tmp = ScColor(c, m, x, k).getRGBColor();
+					tmp = ScColor(c, m, x, k).getDisplayColorGC();
 					break;
 				}
 				p.setBrush(tmp);
@@ -475,13 +477,13 @@ QPixmap CMYKChoose::SliderPix(int farbe)
 				switch (farbe)
 				{
 				case 180:
-					tmp = ScColor(x, 0, 0, 0).getRGBColor();
+					tmp = ScColor(x, 0, 0, 0).getDisplayColorGC();
 					break;
 				case 300:
-				        tmp = ScColor(0, x, 0, 0).getRGBColor();
+				        tmp = ScColor(0, x, 0, 0).getDisplayColorGC();
 					break;
 				case 60:
-					tmp = ScColor(0, 0, x, 0).getRGBColor();
+					tmp = ScColor(0, 0, x, 0).getDisplayColorGC();
 					break;
 				}
 				p.setBrush(tmp);
@@ -495,13 +497,13 @@ QPixmap CMYKChoose::SliderPix(int farbe)
 				switch (farbe)
 				{
 				case 0:
-					tmp = ScColor(x, g, b).getRGBColor();
+					tmp = ScColor(x, g, b).getDisplayColorGC();
 					break;
 				case 120:
-					tmp = ScColor(r, x, b).getRGBColor();
+					tmp = ScColor(r, x, b).getDisplayColorGC();
 					break;
 				case 240:
-					tmp = ScColor(r, g, x).getRGBColor();
+					tmp = ScColor(r, g, x).getDisplayColorGC();
 					break;
 				}
 				p.setBrush(tmp);
@@ -511,13 +513,13 @@ QPixmap CMYKChoose::SliderPix(int farbe)
 				switch (farbe)
 				{
 				case 0:
-					tmp = ScColor(x, 0, 0).getRGBColor();
+					tmp = ScColor(x, 0, 0).getDisplayColorGC();
 					break;
 				case 120:
-				        tmp = ScColor(0, x, 0).getRGBColor();
+				        tmp = ScColor(0, x, 0).getDisplayColorGC();
 					break;
 				case 240:
-					tmp = ScColor(0, 0, x).getRGBColor();
+					tmp = ScColor(0, 0, x).getDisplayColorGC();
 					break;
 				}
 				p.setBrush(tmp);
@@ -541,9 +543,9 @@ QPixmap CMYKChoose::SliderBlack()
 	for (int x = 0; x < 255; x += 5)
 	{
 		if (dynamic)
-			p.setBrush(ScColor(c, m, y, x).getRGBColor());
+			p.setBrush(ScColor(c, m, y, x).getDisplayColorGC());
 		else
-			p.setBrush(ScColor(0, 0, 0, x).getRGBColor());
+			p.setBrush(ScColor(0, 0, 0, x).getDisplayColorGC());
 		p.drawRect(x, 0, 5, 10);
 		val -= 5;
 	}
@@ -664,7 +666,7 @@ void CMYKChoose::SelSwatch(int n)
 		QPixmap pm = QPixmap(30, 15);
 		for (it = CurrSwatch.begin(); it != CurrSwatch.end(); ++it)
 		{
-			pm.fill(CurrSwatch[it.key()].getRGBColor());
+			pm.fill(CurrSwatch[it.key()].getDisplayColor());
 			ColorSwatch->insertItem(pm, it.key());
 		}
 		ColorSwatch->setSelected(ColorSwatch->currentItem(), false);
@@ -810,6 +812,10 @@ void CMYKChoose::SelModel(const QString& mod)
 		Farbe.setColorModel(colorModelRGB);
 		setValues();
 	}
+	imageN.fill(Farbe.getDisplayColor());
+	if (Farbe.isOutOfGamut())
+		paintAlert(alertIcon, imageN, 2, 2, false);
+	NewC->setPixmap( imageN );
 	connect( CyanSp, SIGNAL( valueChanged(int) ), CyanSL, SLOT( setValue(int) ) );
 	connect( MagentaSp, SIGNAL( valueChanged(int) ), MagentaSL, SLOT( setValue(int) ) );
 	connect( YellowSp, SIGNAL( valueChanged(int) ), YellowSL, SLOT( setValue(int) ) );
@@ -882,10 +888,10 @@ void CMYKChoose::setColor()
 			YellowP->setPixmap(SliderPix(240));
 		}
 	}
-	imageN.fill(tmp.getRawRGBColor());
+	imageN.fill(tmp.getDisplayColor());
 	tmp.checkGamut();
 	if (tmp.isOutOfGamut())
-		paintAlert(alertIcon, imageN, 2, 2);
+		paintAlert(alertIcon, imageN, 2, 2, false);
 	tmp.getRGBColor().hsv(&h, &s, &v);
 	NewC->setPixmap( imageN );
 	Farbe = tmp;
@@ -903,9 +909,9 @@ void CMYKChoose::setColor2(int h, int s, bool ende)
 	if (CMYKmode)
 		tmp.setColorModel(colorModelCMYK);
 	tmp.checkGamut();
-	imageN.fill(tmp.getRawRGBColor());
+	imageN.fill(tmp.getDisplayColor());
 	if (tmp.isOutOfGamut())
-		paintAlert(alertIcon, imageN, 2, 2);
+		paintAlert(alertIcon, imageN, 2, 2, false);
 	NewC->setPixmap( imageN );
 	Farbe = tmp;
 	if (ende)
@@ -918,9 +924,9 @@ void CMYKChoose::SelFromSwatch(int c)
 	if (CMYKmode)
 		tmp.setColorModel(colorModelCMYK);
 	tmp.checkGamut();
-	imageN.fill(tmp.getRawRGBColor());
+	imageN.fill(tmp.getDisplayColor());
 	if (tmp.isOutOfGamut())
-		paintAlert(alertIcon, imageN, 2, 2);
+		paintAlert(alertIcon, imageN, 2, 2, false);
 	NewC->setPixmap( imageN );
 	Farbe = tmp;
 	setValues();
